
/*
** Copyright (C) 2003-2004 Herbert Poetzl
**
** V0.01	test for syscall
** V0.02	create, attach, name and id
** V0.03	switched to new syscall stuff
**
*/

#define VERSION "V0.03"

#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <string.h>
#include <signal.h>
#include <unistd.h>
#include <sched.h>
#include <sys/types.h>
#include <sys/wait.h>
#include <sys/mount.h>

#include "vserver.h"
#include "switch.h"
#include "ngnet.h"
#include "ngnet_cmd.h"


static	char	err_flag = 0;

static	char	opt_vers = 0;
static	char	opt_zap = 0;

static	char *	cmd_name = NULL;

static	int 	num_ctx = 0;
static	int 	num_vnet = 0;

static	char *	dev_name = "lo";
static	char *	vndev_name = "lo";



#define OPTIONS "+hx:n:d:D:ZV"

int	main(int argc, char *argv[])
{
        extern int optind;
        extern char *optarg;
        char c, errflg = 0;
	int r;


        cmd_name = argv[0];
        while ((c = getopt(argc, argv, OPTIONS)) != EOF) {
            switch (c) {
            case 'h':
                fprintf(stderr,
                    "This is %s " VERSION "\n"
                    "options are:\n"
                    "-h        print this help message\n"
                    "-x <num>  context id\n"
                    "-n <num>  vnet device id\n"
                    "-d <dev>  real host device name\n"
                    "-D <dev>  vnet device name\n"
                    "-Z        zap (remove) device(s)\n"
                    "-V        verify interface version\n"
                    "--        end of options\n"
                    ,cmd_name);
                exit(0);
                break;
            case 'x':
                num_ctx = atol(optarg);
                break;
            case 'n':
                num_vnet = atol(optarg);
                break;
            case 'd':
                dev_name = optarg;
		vndev_name = optarg;
                break;
            case 'D':
                vndev_name = optarg;
                break;
            case 'Z':
                opt_zap = 1;
                break;
            case 'V':
                opt_vers = 1;
                break;
            case '?':
            default:
                errflg++;
                break;
            }
        }
        if (errflg) {
            fprintf(stderr, 
                "Usage: %s -[" OPTIONS "]\n"
                "%s -h for help.\n",
                cmd_name, cmd_name);
            exit(2);
        }

	if (opt_vers) {
	    r = vserver(VCMD_get_version, 0, NULL);
	    if (r<0)
	    	perror("vc_get_version");
    	    else 
	    	printf("version: %04x:%04x\n", 
		    (r>>16)&0xFFFF, r&0xFFFF);
	}


	if (opt_zap) {
	    struct vcmd_zap_vnet_v0 data;

	    data.vnet = num_vnet;
	    data.flags = 0;
	    r = vserver(VCMD_zap_vnet, num_ctx, &data);
	    if (r)
	    	perror("vc_zap_vnet");
	} else {
	    struct vcmd_add_vndev_v0 data;

	    data.vnet = num_vnet;
	    data.flags = 0;
	    strncpy(data.real, dev_name, IFNAMSIZ);
	    strncpy(data.name, vndev_name, IFNAMSIZ);
	    r = vserver(VCMD_add_vndev, num_ctx, &data);
	    if (r)
	    	perror("vc_add_vndev");
	}
	
	exit((err_flag)?1:0);
}

